function f=fit(x,func)
global t
t=t+1;
global fMax

D=numel(x);
switch func
  case -3  % Just for test
  f=1;
    a=10/3;
    for d=1:D
      xd=x(d);
      f=f*(sin(xd) + rand()*sin(a*xd));
    end
    f=f+2;
  
  case -2
    f=1;
    for d=1:D
      xd=x(d)-3;
      f=f*abs((sin(xd)+0.1*xd));
    end
    
  case -1 % Planes
    f=sum(abs(x-3));
    
  case 0 % Paraboloid
    f=0;
    for d=1:D
      f=f+(x(d)-4+d)^2;
    end
    
  case 1 % Shifted Rastrigin
    % min 0
    % Easy
    f=10*D;
    for d=1:D
      xd=x(d)-3+d/10;
      f =f+ xd^2 - 10*cos(2*acos(-1)*xd);
    end
    
  case 2 % Inverted Shifted Rastrigin
    % Easy
    f=0;
    for d=1:D
      xd=x(d);
      f = f + (xd-3)^2 - 10*cos(2*acos(-1)*(xd-3));
    end
    f=159*D-f;
    
  case 3 % Inverted Paraboloid
         % Too easy
    f=49*D;
    for d=1:D
      f=f-(x(d)-3)^2;
    end
    
  case 4 % Multiple Paraboloids
    % Easy
    f=0;
    for d=1:D
      xd=x(d);
      if xd<5
        f=f+(xd-3)^2;
      else
        f=f+1+(xd-7)^2;
      end
    end
    
  case 5 % Inverted Multiple Paraboloids
    % Too easy
    f=0;
    for d=1:D
      xd=x(d);
      if xd<5
        f=f+(xd-3)^2;
      else
        f=f+1+(xd-7)^2;
      end
    end
    f=10*D-f;
    
  case 6 % Shifted Decreasing Increasing sin
    % Easy
    f=0;
    for d=1:D
      xd=x(d)-4+d;
      f=f+sin(xd)^2+abs(xd);
    end
    
  case 7 % Plateau with cave
    % Easy, but difficult with smaller "width"
    posMin=0.3*ones(1,D);
    if size(posMin,1)~=size(x,1) posMin=posMin'; end
    width=0.1; 
    r= pdist([x;posMin],'euclidean');
    if r<=width
      f=r^2;
    else
      f=width^2;
    end
    
  case 8 % Cubic
    % Easy
    f=0;
    for d=1:D
      f=f+(x(d)-4+d)^3;
    end
    
  case 9 % Rosenbrock
    % min 0 on (1,1...,1)
    % Easy
    f = 0;
    for d = 1:D-1
      zi=x(d);
      zi1=x(d+1);
      f = f + 100*((zi1 - zi^2)^2) + (1 - zi)^2;
    end
    
  case 10 % Six Hump Camel Back
    % min −1.031628453489877
    % at (±0.08984201368301331,±0.7126564032704135)
    % Easy   
    x1=x(1); x2=x(2);
    f=	(4-2.1*x1^2+x1^4/3)*x1^2+x1*x2+(-4+4*x2^2)*x2^2;
    
  case 11 % Pressure Vessel D=4
    % f(0.8125 0.4375 42.0984455958549 176.6365958424394)=6059.714335048436
    % "True global optimality of the pressure vessel design problem" 
    %  by Xin-She Yang
    % Difficult (because partly discrete)
    q=0.0625;
    x1=q*round(x(1)/q);
    x2=q*round(x(2)/q);
    f=0.6224*x1*x(3)*x(4) + 1.7781*x2*x(3)*x(3) ...
      + x1*x1*(3.1661*x(4) +19.84*x(3));
    
    % Takes constraints into account (penalty method)
    g(1)=0.0193*x(3)-x(1);
    g(2)=0.00954*x(3)-x(2);
    g(3)=1296000-pi*x(3)*x(3)*(x(4)+4*x(3)/3);
    
    pw=10^10;
    if g(1)>0 c= 1+pw*g(1);  f=f*c*c; end
    if g(2)>0 c=1+pw*g(2); f=f*c*c;  end
    if g(3)>0 c=1+pw*g(3); f=f*c*c;  end
    
  case 12 % Gear train D=4
    % Min 2.700857e-12 at (16 19 43 49)
    % Difficult (because partly discrete)
    z=1.0/6.931;
    f=z-x(1)*x(2)/(x(3)*x(4));
    f=f*f;
    
  case 13 % Shifted Griewank.
    % Min 0. 
    % Difficult (stagnation) for D>1
    s=0; p=1;
    for d=1:D
      xd=x(d)-4+d/10;
      s=s+xd^2;
      p=p*cos(xd)/sqrt(d);
    end
    f=1+s/4000-p;
    
  case 14 % Sin Sin
    % For D=1 min≈-1.8996 at x≈5.14574
    % Easy
    f=1;
    a=10/3;
    for d=1:D
      xd=x(d);
      f=f*(sin(xd) + sin(a*xd));
    end
    
  case 15 % Frequency-Modulated (FM) Sound Waves
    % Minimum 0 at (1, 5, -1.5, 4.8, 2, 4.9)
    % COUNTER EXAMPLE
    theta=2*pi/100;
    f=0;
    for tt=1:100
      y_t=x(1)*sin(x(2)*tt*theta+x(3)*sin(x(4)*tt*theta+x(5)*sin(x(6)*tt*theta)));
      y_0_t=1*sin(5*tt*theta-1.5*sin(4.8*tt*theta+2*sin(4.9*tt*theta)));
      f=f+(y_t-y_0_t)^2;
    end
    
  case 152 % D=5
    % Very difficult
    theta=2*pi/100;
    f=0;
    for tt=1:100
      y_t=sin(x(1)*tt*theta+x(2)*sin(x(3)*tt*theta+x(4)*sin(x(5)*tt*theta)));
      y_0_t=sin(5*tt*theta-1.5*sin(4.8*tt*theta+2*sin(4.9*tt*theta)));
      f=f+(y_t-y_0_t)^2;
    end
    
  case 153 % D=4
    % Difficult
    theta=2*pi/100;
    f=0;
    for tt=1:100
      y_t=1*sin(5*tt*theta+x(1)*sin(x(2)*tt*theta+x(3)*sin(x(4)*tt*theta)));
      y_0_t=1*sin(5*tt*theta-1.5*sin(4.8*tt*theta+2*sin(4.9*tt*theta)));
      f=f+(y_t-y_0_t)^2;
    end
    
  case 154 % D=3
    % Difficult
    theta=2*pi/100;
    f=0;
    for tt=1:100
      y_t=1*sin(5*tt*theta-1.5*sin(x(1)*tt*theta+x(2)*sin(x(3)*tt*theta)));
      y_0_t=1*sin(5*tt*theta-1.5*sin(4.8*tt*theta+2*sin(4.9*tt*theta)));
      f=f+(y_t-y_0_t)^2;
    end
    
  case 155 % D=2
    % Relatively easy
    theta=2*pi/100;
    f=0;
    for tt=1:100
      y_t=1*sin(5*tt*theta-1.5*sin(4.8*tt*theta+x(1)*sin(x(2)*tt*theta)));
      y_0_t=1*sin(5*tt*theta-1.5*sin(4.8*tt*theta+2*sin(4.9*tt*theta)));
      f=f+(y_t-y_0_t)^2;
    end
    
  case 156 % D=1
    % Easy
    theta=2*pi/100;
    f=0;
    for tt=1:100
      y_t=1*sin(5*tt*theta-1.5*sin(4.8*tt*theta+2*sin(x(1)*tt*theta)));
      y_0_t=1*sin(5*tt*theta-1.5*sin(4.8*tt*theta+2*sin(4.9*tt*theta)));
      f=f+(y_t-y_0_t)^2;
    end
    
  case 16 %The bifunctional catalyst blend optimal control problem
    % D=1. Easy
    tol=1.0e-01;% tol is a matter of concern. decreasing it make algo fast.
    tspan=[0 0.78];% check for the range
    yo =[1 0 0 0 0 0 0];
    u=x;%u should be passed here.
    options = odeset('RelTol',tol);
    [~,Y] = ode45(@(tt,y) diffsolv(tt,y,u),tspan,yo,options);
    w=size(Y);
    f=Y(w(1),w(2))*1e+003;
    
    
  case 17 % CEC 2011. Transmission Network Expansion Planning
    f=cec2011_TNEP(x);
    
    %...
    
  case 39 % Branin
    % minimum 0.397887
    % Easy
    x1=x(1);
    x2=x(2);
    f=(x2 - x1^2*5.1/(4*pi^2) +x1*5/pi -6)^2 +10*(1-1/(8*pi))*cos(x1) +10;
    
  case 40 % Beale
    % f(3,0.5)=0
    % Easy
    x1=x(1); x2=x(2);
    f=(1.5-x1+x1*x2)^2 + (2.25 -x1+x1*x2^2)^2 + (2.625-x1+x1*x2^3)^2;
    
  case 41 % Eggholder
    % f(512, 404.2319)=-959.6407
    % Very difficult (solution on the boundary)
    % See Eggholder +
    x1=x(1) ; x2=x(2);
    f=-(x2+47)*sin(sqrt(abs(x1/2 + x2 +47))) ...
      -x1*sin(sqrt(abs(x1-x2-47)));
    
  case 42  % Eggholder +
    % f(512, 404.2319)=-959.6407
    % Very difficult (needs at least 150000 FE)
    if max(abs(x))>512
        f=fMax;
    else
        x1=x(1) ; x2=x(2);
        f=-(x2+47)*sin(sqrt(abs(x1/2 + x2 +47))) ...
            -x1*sin(sqrt(abs(x1-x2-47))); 
    end
    
  case 43 % Schaffer 2
    % f(0,0)=0
    % Too easy
     x1=x(1) ; x2=x(2);
     a=sin(x1^2-x2^2)^2 -0.5;
     b=1+0.001*(x1^2+x2^2);
    f=0.5+a/b^2;
   
  case 44 % Shifted Schaffer 2
    % f(10,20)=0
    % Easy
     x1=x(1)-10 ; x2=x(2)-20;
     a=sin(x1^2-x2^2)^2 -0.5;
     b=1+0.001*(x1^2+x2^2);
    f=0.5+a/b^2;
    
  case 45 % Drop Wave
    % f(0,0)=-1
    % Too easy
    x1 = x(1);
    x2 = x(2);
    a = 1 + cos(12*sqrt(x1^2+x2^2));
    b = 0.5*(x1^2+x2^2) + 2;
    f = -a/b;
    
  case 46 % Shifted Drop Wave
    % f(1,-2)=0
    % Difficult. 
    x1 = x(1)-1;
    x2 = x(2)+2;
    a = 1 + cos(12*sqrt(x1^2+x2^2));
    b = 0.5*(x1^2+x2^2) + 2;
    f = -a/b;
    
  case 47 % Holder Table
    % min -19.85, four solutions (+-p, +-q) 
    % p=8.05502, q=9.
    % Very difficult
    x1 = x(1);
    x2 = x(2);   
    a = sin(x1)*cos(x2);
    b = exp(abs(1 - sqrt(x1^2+x2^2)/pi));
    f = -abs(a*b);
    
  case 48 % Langermann 2D
    % Very difficult
    f=langer(x);
    
  case 49 % Lévy
    % min 0 at (1,1,...,1)
    % Easy
    f=levy(x);
    
  case 50 % Shubert
    % min -186.7309
    % Relatively easy. 50000 FE on 2D
    f=shubert(x);
    
  case 51 % Perm 0 D B
    % min 0 at (1,1/2,...,1/D)
    % Stagnation at a local minimum of very small value
    f=perm0db(x);
end

fMax=max(fMax,f);
end